Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(78)

Unified Diff: webrtc/api/dtlsidentitystore.cc

Issue 1766673002: DtlsIdentityStoreInterface::RequestIdentity: const& parameters (Closed) Base URL: https://chromium.googlesource.com/external/webrtc.git@master
Patch Set: Corrected a misspelling Created 4 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: webrtc/api/dtlsidentitystore.cc
diff --git a/webrtc/api/dtlsidentitystore.cc b/webrtc/api/dtlsidentitystore.cc
index 31c9bc05434bdd6163a1c566a39d1c9f3284f4d1..afd6e6455852209e029fa598d46f60c22e3f37fe 100644
--- a/webrtc/api/dtlsidentitystore.cc
+++ b/webrtc/api/dtlsidentitystore.cc
@@ -123,12 +123,12 @@ DtlsIdentityStoreImpl::~DtlsIdentityStoreImpl() {
void DtlsIdentityStoreImpl::RequestIdentity(
rtc::KeyParams key_params,
- rtc::Optional<uint64_t> expires,
+ const rtc::Optional<uint64_t>& expires_ms,
const rtc::scoped_refptr<DtlsIdentityRequestObserver>& observer) {
RTC_DCHECK(signaling_thread_->IsCurrent());
RTC_DCHECK(observer);
// Dropping parameterization and |expires|.
// TODO(hbos,torbjorng): Use parameterizaton/expiration. webrtc:5092.
GenerateIdentity(key_params.type(), observer);
}
@@ -123,12 +123,12 @@ DtlsIdentityStoreImpl::~DtlsIdentityStoreImpl() {
RTC_DCHECK(signaling_thread_->IsCurrent());
RTC_DCHECK(observer);
- // Dropping parameterization and |expires|.
+ // Dropping parameterization and |expires_ms|.
// TODO(hbos,torbjorng): Use parameterizaton/expiration. webrtc:5092.
GenerateIdentity(key_params.type(), observer);

Powered by Google App Engine
This is Rietveld 408576698